API
=====================

py\_sc\_fermi.defect\_charge\_state module
------------------------------------------

.. automodule:: py_sc_fermi.defect_charge_state
   :members:
   :undoc-members:
   :show-inheritance:

py\_sc\_fermi.defect\_species module
------------------------------------

.. automodule:: py_sc_fermi.defect_species
   :members:
   :undoc-members:
   :show-inheritance:

py\_sc\_fermi.defect\_system module
-----------------------------------

.. automodule:: py_sc_fermi.defect_system
   :members:
   :undoc-members:
   :show-inheritance:

py\_sc\_fermi.dos module
------------------------

.. automodule:: py_sc_fermi.dos
   :members:
   :undoc-members:
   :show-inheritance:

py\_sc\_fermi.inputs module
---------------------------

.. automodule:: py_sc_fermi.inputs
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: py_sc_fermi
   :members:
   :undoc-members:
   :show-inheritance:
